# Changelog

---
## [0.1.14] - 2025-02-25
## [0.1.13] - 2025-02-25
## [0.1.12] - 2025-02-25
### improvements
- fixed metadata issue in file uploader
- added user_id[Optional parameter] to trace user activity
- changed api url for file upload

---
## [0.1.11] - 2025-02-21
## [0.1.10] - 2025-02-21
### imporvements
- added version to the package
- fixed package installation issue
---
## [0.1.8] - [0.1.9]- 2025-02-12
### imporvements
- package name renaming as per python naming convention

---
## [0.1.7] - 2025-02-12
### imporvements
- added project meta data for better visiblity and issue tracking

---
## [0.1.6] - 2025-02-12
### imporvements
- added changelog to track updates

---
## [0.1.5] - 2025-02-12
- **Beta Release**
### Initial Release
- Core SDK functionalities:
  - **File Upload**
  - **Agent Service**
  - **Extractions Service**
- Support for Python 3.7+.
- Added structured error handling.
- documented proper examples
- incorporated unit tests for stability

---

### Notes:
- Breaking changes, if any, will be highlighted in future versions.
- Follow our [GitHub Releases](https://github.com/splorehq/splore-sdk-py/releases) for updates.